@@ -19,7 +19,7 @@ logger = daiquiri.getLogger(__name__)
 
 def update_chart(chart_shape: GraphicFrame, *, chart_spec: ChartSpec, repo: SeriesRepo, slide: Slide) -> None:
     chart = cast(Chart, chart_shape.chart)
-    if chart.chart_type == XL_CHART_TYPE.LINE:
+    if chart.chart_type in {XL_CHART_TYPE.LINE, XL_CHART_TYPE.LINE_MARKERS}:
         if not isinstance(chart.category_axis, DateAxis):
             raise NotImplementedError(chart.category_axis)
         update_time_series_chart(chart_shape, chart_spec=chart_spec, repo=repo, slide=slide)
