@@ -1,3 +1,5 @@
+from typing import Any
+
 from pptx.chart.chart import Chart
 from pptx.chart.series import _BaseCategorySeries
 from pptx.dml.color import RGBColor
@@ -8,8 +10,10 @@ from dbnomics_pptx_tools.charts.utils import iter_chart_series_with_spec
 from dbnomics_pptx_tools.metadata import ChartSpec, SeriesFormatSpec
 
 
-def update_series(chart: Chart, *, chart_spec: ChartSpec) -> None:
-    for chart_series, series_spec in iter_chart_series_with_spec(chart, chart_spec):
+def update_series(chart: Chart, *, chart_series_attrs: dict[str, dict[str, Any]], chart_spec: ChartSpec) -> None:
+    for chart_series, series_spec in iter_chart_series_with_spec(
+        chart, chart_series_attrs=chart_series_attrs, chart_spec=chart_spec
+    ):
         format_spec = series_spec.format
         if format_spec is not None:
             update_series_format(chart_series, format_spec=format_spec)
