@@ -1,4 +1,4 @@
-from typing import Iterator
+from typing import Any, Iterator
 
 import daiquiri
 from pptx.chart.chart import Chart
@@ -10,11 +10,15 @@ logger = daiquiri.getLogger(__name__)
 
 
 def iter_chart_series_with_spec(
-    chart: Chart, chart_spec: ChartSpec
+    chart: Chart,
+    *,
+    chart_series_attrs: dict[str, dict[str, Any]],
+    chart_spec: ChartSpec,
 ) -> Iterator[tuple[_BaseCategorySeries, SeriesSpec]]:
     chart_series_by_name = {chart_series.name: chart_series for chart_series in chart.series}
     for series_spec in chart_spec.series:
-        series_name = series_spec.name
+        series_attrs = chart_series_attrs.get(series_spec.id, {})
+        series_name = series_spec.name.format(**series_attrs)
         chart_series = chart_series_by_name.get(series_name)
         if chart_series is None:
             logger.warning("Could not find the chart series corresponding to the series name %r, ignoring", series_name)
