@@ -133,6 +133,7 @@ def update(
         True, help="Fetch series when it is not found in the cache, then add it to the cache."
     ),
     dbnomics_api_cache_dir: Path = typer.Option(DBNOMICS_API_CACHE_DIR_NAME),
+    fail_fast: bool = typer.Option(False, help="Raise exception when failing to update a slide."),
     force: bool = typer.Option(False, help="Fetch a series even if it is already stored in the cache."),
     metadata_file: Path = typer.Option(..., exists=True, readable=True),
     only_slides_expr: Optional[str] = typer.Option(None, "--slides"),
@@ -158,7 +159,9 @@ def update(
     repo = SeriesRepo(auto_fetch=auto_fetch, cache=cache, force=force)
 
     try:
-        update_slides(prs, only_slides=only_slides, presentation_metadata=presentation_metadata, repo=repo)
+        update_slides(
+            prs, fail_fast=fail_fast, only_slides=only_slides, presentation_metadata=presentation_metadata, repo=repo
+        )
     except SeriesLoadError as exc:
         typer.echo(f'{str(exc)} Hint: use the --auto-fetch option or run the "fetch" command first.')
         raise typer.Exit(1)
