@@ -36,25 +36,9 @@ class SeriesRepo:
         df: DataFrame = fetch_series(series_ids=[series_id])
         if df.empty:
             return df
-        df = self._remove_dimension_columns(df)
         df = self._add_series_id_column(df)
         return df
 
-    def _remove_dimension_columns(self, df: DataFrame) -> DataFrame:
-        columns_to_keep = [
-            "@frequency",
-            "provider_code",
-            "dataset_code",
-            "dataset_name",
-            "series_code",
-            "series_name",
-            "original_period",
-            "period",
-            "original_value",
-            "value",
-        ]
-        return df[columns_to_keep]
-
 
 class SeriesLoadError(Exception):
     def __init__(self, *, repo: SeriesRepo, series_id: str):
