@@ -122,7 +122,7 @@ def find_header_row_index(table: Table, *, table_spec: TableSpec | None) -> int
 def find_latest_column_period(table_series_df: DataFrame) -> pd.Period:
     logger.debug("Finding the period of the latest column from table series")
     return pd.Period(
-        max(sub_df["original_period"].iloc[-1] for _, sub_df in table_series_df.dropna().groupby("series_id"))
+        max(sub_df["original_period"].dropna().iloc[-1] for _, sub_df in table_series_df.groupby("series_id"))
     )
 
 
